Utf8ByteType

Enum Utf8ByteType 

pub enum Utf8ByteType {
    Continuation,
    Single,
    Double,
    Triple,
    Quadruple,
}
Categorization of a valid byte in UTF-8

Example

use utf8_parser::Utf8ByteType;

assert_eq!(Utf8ByteType::of(0b00000010)?, Utf8ByteType::Single);
assert_eq!(Utf8ByteType::of(0b10000010)?, Utf8ByteType::Continuation);
assert_eq!(Utf8ByteType::of(0b11000010)?, Utf8ByteType::Double);
assert_eq!(Utf8ByteType::of(0b11100010)?, Utf8ByteType::Triple);
assert_eq!(Utf8ByteType::of(0b11110010)?, Utf8ByteType::Quadruple);
assert!(Utf8ByteType::of(0b11111010).is_err());

Variants



Continuation

A continuation byte



Single

A one-byte UTF-8 character, i.e. an ASCII value



Double

A start byte that must be followed by one continuation byte



Triple

A start byte that must be followed by two continuation bytes



Quadruple

A start byte that must be followed by three continuation bytes

Implementations

Source

impl Utf8ByteType

pub const fn of(byte: u8) -> Result<Self, Utf8ParserError>

Get type of byte

pub const fn is_continuation(self) -> bool

Returns true if this is a continuation byte