pub enum Utf8ParserError {
InvalidByte(u8),
InvalidChar(u32),
UnexpectedStartByte(u8),
UnexpectedContinuationByte(u8),
OverlongEncoding,
}Expand description
Error type used for the utf8-parser crate
Variants
InvalidByte(u8)
Encountered an invalid byte. This is a byte that’s invalid no matter the context.
InvalidChar(u32)
Found a code point that’s not valid UTF-8.
UnexpectedStartByte(u8)
Found a start byte in an unexpected place
UnexpectedContinuationByte(u8)
Found a continuation byte in an unexpected place
OverlongEncoding
Represented a valid code point in a longer form than necessary.
From Wikipedia:
The standard specifies that the correct encoding of a code point uses only the minimum number of bytes required to hold the significant bits of the code point. Longer encodings are called overlong and are not valid UTF-8 representations of the code point. This rule maintains a one-to-one correspondence between code points and their valid encodings, so that there is a unique valid encoding for each code point. This ensures that string comparisons and searches are well-defined.